@@ -126,6 +126,7 @@ class WebBrowser:
       self.logger.warning("Hay quay lai website")
 
   def waitElementOut(self, action_name, bytype, str_find, timeout, delay, interval):
+    self.driver.implicitly_wait(interval)
     result = None
     times  = int(timeout / interval)
     not_found_times = 0
@@ -146,6 +147,7 @@ class WebBrowser:
       except:
         result = None
         break
+    self.driver.implicitly_wait(20)
     return result
 
   def searchElement(self, element_name, bytype, str_find, timeout, delay, interval):
@@ -239,7 +241,7 @@ class WebBrowser:
         search.send_keys(file_cd)
         search = self.searchClick('fileAnhCaNhan', 'XPATH', '//*[@id="body-dialog"]/mat-toolbar/section/div/button[6]', 20,0,2)
         search = self.searchClick('fileAnhCaNhan', 'XPATH', '//*[@id="body-dialog"]/mat-toolbar/section/div/button[6]', 4,0,2)
-        search = self.waitElementOut('fileAnhCaNhan','XPATH', '//*[@id="footer-dialog"]/button/span', 30,0, 2)
+        search = self.waitElementOut('fileAnhCaNhan','XPATH', '//*[@id="footer-dialog"]/button/span', 30,0, 1)
         if search:
           self.searchClick('fileAnhCaNhan', 'XPATH', '//*[@id="footer-dialog"]/button/span', 4,0,2)
       else:
@@ -255,7 +257,7 @@ class WebBrowser:
         if os.path.exists(file_mt):
           search = self.searchElement("fileAnhCmndMatTruoc", 'ID', 'fileAnhCmndMatTruoc', 10, 0,2)
           search.send_keys(file_mt)
-          search = self.waitElementOut('fileAnhCmndMatTruoc', 'XPATH', '//*[@id="footer-dialog"]/button/span', 60,0, 2)
+          search = self.waitElementOut('fileAnhCmndMatTruoc', 'XPATH', '//*[@id="footer-dialog"]/button/span', 60,0, 1)
           if search:
             self.searchClick('fileAnhCmndMatTruoc', 'XPATH', '//*[@id="footer-dialog"]/button/span', 4,0,2)
         else:
@@ -263,7 +265,7 @@ class WebBrowser:
           if os.path.exists(file_mt):
             search = self.searchElement("fileAnhCmndMatTruoc", 'ID', 'fileAnhCmndMatTruoc', 10, 0,2)
             search.send_keys(file_mt)
-            self.searchClick('fileAnhCaNhan', 'XPATH', '//*[@id="body-dialog"]/mat-toolbar/section/div/button[6]', 10,0,2)
+            self.searchClick('fileAnhCmndMatTruoc', 'XPATH', '//*[@id="body-dialog"]/mat-toolbar/section/div/button[6]', 10,0,2)
             self.searchClick('fileAnhCmndMatTruoc','XPATH', '//*[@id="footer-dialog"]/button/span', 10,0, 2)
 
       #cmnd mat sau
@@ -271,7 +273,7 @@ class WebBrowser:
         if os.path.exists(file_ms):
           search = self.searchElement("fileAnhCmndMatSau", 'ID', 'fileAnhCmndMatSau', 10, 0,2)
           search.send_keys(file_ms)
-          search = self.waitElementOut('fileAnhCmndMatSau','XPATH', '//*[@id="footer-dialog"]/button/span', 60,0, 2)
+          search = self.waitElementOut('fileAnhCmndMatSau','XPATH', '//*[@id="footer-dialog"]/button/span', 60,0, 1)
           if search:
             self.searchClick('fileAnhCmndMatSau', 'XPATH', '//*[@id="footer-dialog"]/button/span', 4,0,2)
         else:
@@ -279,7 +281,7 @@ class WebBrowser:
           if os.path.exists(file_ms):
             search = self.searchElement("fileAnhCmndMatSau", 'ID', 'fileAnhCmndMatSau', 10, 0,2)
             search.send_keys(file_ms)
-            self.searchClick('fileAnhCaNhan', 'XPATH', '//*[@id="body-dialog"]/mat-toolbar/section/div/button[6]', 10,0,2)
+            self.searchClick('fileAnhCmndMatSau', 'XPATH', '//*[@id="body-dialog"]/mat-toolbar/section/div/button[6]', 10,0,2)
             self.searchClick('fileAnhCmndMatSau','XPATH', '//*[@id="footer-dialog"]/button/span', 10,0, 2)
 
     #cmnd_str
